This function takes a K-means model fit using kmeans and returns a list-of-lists representing in valid PFA document that could be used for scoring
# S3 method for kmeans
pfa(object, name = NULL, version = NULL, doc = NULL,
metadata = NULL, randseed = NULL, options = NULL,
cluster_names = NULL, ...)an object of class "kmeans"
a character which is an optional name for the scoring engine
an integer which is sequential version number for the model
a character which is documentation string for archival purposes
a list of strings that is computer-readable documentation for
archival purposes
a integer which is a global seed used to generate all random numbers. Multiple scoring engines derived from the same PFA file have different seeds generated from the global one
a list with value types depending on option name
Initialization or runtime options to customize implementation
(e.g. optimization switches). May be overridden or ignored by PFA consumer
a character vector of length k to name the values relating to each cluster instead of just an integer. If not specified, then the predicted cluster will be the string representation of the cluster index.
additional arguments affecting the PFA produced
a list of lists that compose valid PFA document
model <- kmeans(x=iris[, 1:2], centers=3)
model_as_pfa <- pfa(model)
Run the code above in your browser using DataLab