powered by
Builds an entire PFA list of lists based on a naiveBayes
# S3 method for naiveBayes build_model(object, threshold = 0.001, eps = 0, ...)
a object of class naiveBayes
a value replacing cells with probabilities within eps range.
a numeric for specifying an epsilon-range to apply laplace smoothing (to replace zero or close-zero probabilities by theshold.)
further arguments passed to or from other methods
a list of lists representation of the naiveBayes model that can be inserted into a cell or pool
list
model <- e1071::naiveBayes(Species ~ ., data=iris) model_built <- build_model(model)
Run the code above in your browser using DataLab